# lessコマンド

テキストファイルを検索機能付きのスクロール可能なインターフェースで表示します。

## 概要

`less`はターミナルページャープログラムで、テキストファイルを一度に1画面ずつ表示することができます。ファイル全体を一度に表示する`cat`とは異なり、`less`は前後の移動、テキスト検索などのナビゲーション機能を提供します。特に大きなファイルをターミナルに負担をかけずに表示するのに便利です。

## オプション

### **-N**

各行の先頭に行番号を表示します。

```console
$ less -N file.txt
      1 This is line 1
      2 This is line 2
      3 This is line 3
```

### **-i**

大文字と小文字を区別しない検索を行います。このオプションを有効にすると、「text」を検索すると「text」、「Text」、「TEXT」などにマッチします。

```console
$ less -i file.txt
```

### **-S**

行の折り返しを無効にします。長い行は次の行に折り返されるのではなく、切り詰められ、水平スクロールが可能になります。

```console
$ less -S file.txt
```

### **-F**

ファイル全体が最初の画面に表示できる場合、自動的に終了します。

```console
$ less -F short_file.txt
```

### **-R**

ANSIカラーエスケープシーケンスをそのままの形で表示し、色付きテキストを適切に表示できるようにします。

```console
$ less -R colored_output.txt
```

### **-X**

lessを終了する際に画面をクリアせず、内容をターミナルに表示したままにします。

```console
$ less -X file.txt
```

## 使用例

### 基本的なファイル表示

```console
$ less /var/log/syslog
[スクロール可能なインターフェースでファイル内容が表示される]
```

### コマンド出力の表示

```console
$ ls -la | less
total 112
drwxr-xr-x  18 user  staff   576 May  5 10:23 .
drwxr-xr-x   5 user  staff   160 Apr 29 14:12 ..
-rw-r--r--   1 user  staff  8196 May  5 09:45 file1.txt
-rw-r--r--   1 user  staff  5423 May  4 16:32 file2.txt
```

### 圧縮ファイルの表示

```console
$ zless compressed_file.gz
[スクロール可能なインターフェースで解凍された内容が表示される]
```

## ナビゲーションコマンド

less内では、以下のキーボードコマンドが使用できます：

- **スペース/Page Down**：1画面進む
- **b/Page Up**：1画面戻る
- **下矢印/Enter**：1行進む
- **上矢印**：1行戻る
- **g**：最初の行に移動
- **G**：最後の行に移動
- **/パターン**：「パターン」を前方検索
- **n**：最後の検索を前方に繰り返す
- **N**：最後の検索を後方に繰り返す
- **q**：lessを終了

## ヒント：

### クイックナビゲーション用の位置マーク

`m`を押した後に任意の文字を押すと、現在の位置をマークできます。後で`'`（アポストロフィ）を押した後に同じ文字を押すと、その位置に戻ることができます。

### 成長するファイルの追跡

`less +F file.log`を使用して成長するファイルを追跡します（`tail -f`と同様）。Ctrl+Cを押すと追跡を停止し、通常のブラウジングモードに戻ります。`F`を押すと追跡を再開します。

### 環境変数でエクスペリエンスをカスタマイズ

シェル設定で`LESS="-R -i"`を設定すると、それらのオプションを入力しなくても常に使用できます。

### 複数ファイルのナビゲーション

`less file1 file2 file3`で複数のファイルを開いた場合、`:n`で次のファイルに移動し、`:p`で前のファイルに移動します。

## よくある質問

#### Q1. `less`と`more`の違いは何ですか？
A. `less`は`more`の改良版で、双方向スクロール、より優れた検索機能を持ち、表示前にファイル全体を読み込む必要がありません。

#### Q2. ファイル内のテキストを検索するにはどうすればよいですか？
A. `/`を押した後に検索語を入力してEnterを押します。`n`で次の出現箇所を、`N`で前の出現箇所を見つけます。

#### Q3. 行番号を表示するにはどうすればよいですか？
A. `less -N ファイル名`を使用するか、lessでファイルを表示中に`-N`を押します。

#### Q4. lessを終了するにはどうすればよいですか？
A. `q`を押して終了します。

#### Q5. lessでバイナリファイルを表示できますか？
A. lessはバイナリファイルを開くことができますが、テキスト用に設計されています。バイナリファイルの場合は、`hexdump`や`xxd`などの専用ツールの使用を検討してください。

## 参考文献

https://www.greenwoodsoftware.com/less/

## 改訂履歴

- 2025/05/05 初版