# more コマンド

ファイルの内容を一度に1画面ずつ表示します。

## 概要

`more`はテキストを1画面ずつページングするためのフィルターです。テキストファイルの内容を制御された方法で表示し、ユーザーがファイル内を前方に移動できるようにします。より高機能な`less`とは異なり、`more`は主に前方への移動のみを可能にします。

## オプション

### **-d**

役立つプロンプトを表示し、よりユーザーフレンドリーなエラーメッセージを提供します。

```
$ more -d large_file.txt
--More--(50%) [スペースキーで続行、'q'で終了。]
```

### **-f**

画面行ではなく論理行をカウントします（折り返される長い行で便利）。

```
$ more -f wrapped_text.txt
```

### **-p**

各ページを表示する前に画面をクリアします。

```
$ more -p document.txt
```

### **-c**

表示前に画面をクリアしますが、上の行から描画することで行います。

```
$ more -c large_file.txt
```

### **-s**

複数の空白行を1行に圧縮します。

```
$ more -s file_with_blanks.txt
```

### **-u**

下線を抑制します（一部の端末タイプで便利）。

```
$ more -u formatted_text.txt
```

### **-number**

1画面あたりの行数を設定します。

```
$ more -10 short_file.txt
```

### **+number**

指定した行番号からファイルの表示を開始します。

```
$ more +100 large_file.txt
```

### **+/pattern**

パターンを含む最初の行から表示を開始します。

```
$ more +/ERROR log_file.txt
```

## 使用例

### 基本的な使用法

```
$ more /etc/passwd
root:x:0:0:root:/root:/bin/bash
daemon:x:1:1:daemon:/usr/sbin:/usr/sbin/nologin
bin:x:2:2:bin:/bin:/usr/sbin/nologin
--More--(28%)
```

### 複数ファイルの表示

```
$ more file1.txt file2.txt
::::::::::::::
file1.txt
::::::::::::::
Contents of file1...
--More--(75%)
```

### コマンド出力をmoreにパイプする

```
$ ls -la /usr/bin | more
total 123456
drwxr-xr-x  2 root root   69632 Apr 18 09:23 .
drwxr-xr-x 14 root root    4096 Jan 15 12:34 ..
-rwxr-xr-x  1 root root   35344 Feb  7  2022 [
--More--(2%)
```

### 特定のパターンから開始

```
$ more +/function script.js
function calculateTotal() {
  // Function implementation
}
--More--(45%)
```

## ヒント

### ナビゲーションコマンド

`more`でファイルを表示している間、以下のコマンドが使用できます：
- `Space` - 1画面分前進
- `Enter` - 1行前進
- `b` - 1画面分後退（すべての実装で動作しない場合があります）
- `q` - 終了
- `/pattern` - パターンを検索
- `n` - 前回の検索を繰り返す

### 大きなファイルでmoreを使用する

非常に大きなファイルの場合、`more`は読み込み時にファイルをロードするため、ファイル全体を一度にロードするよりもメモリ効率が良くなります。

### lessを代わりに使用する場合

より柔軟にファイル内を前後に移動する必要がある場合は、より多くの機能を提供する`less`の使用を検討してください。

### プロンプトのカスタマイズ

`MORE`環境変数を設定してプロンプトと動作をカスタマイズできます：
```
$ export MORE="-d"
```

## よくある質問

#### Q1. `more`と`less`の違いは何ですか？
A. `more`はファイル内を主に前方に移動できる古いユーティリティです。`less`はより機能が豊富で、前後の移動が可能で、追加の検索機能も備えています。

#### Q2. `more`を終了するにはどうすればよいですか？
A. `q`キーを押して終了します。

#### Q3. `more`でテキストを検索できますか？
A. はい、`/`に続けて検索パターンを入力し、Enterを押します。次の出現を見つけるには`n`を使用します。

#### Q4. `more`で行番号を表示するにはどうすればよいですか？
A. `more`には組み込みの行番号表示機能はありません。行番号を表示するには、`less -N`または`cat -n file.txt | more`の使用を検討してください。

#### Q5. `more`で一度に特定の行数を表示するにはどうすればよいですか？
A. `-number`オプションを使用します。例えば、`more -20 file.txt`で一度に20行表示します。

## 参考文献

https://man7.org/linux/man-pages/man1/more.1.html

## 改訂履歴

- 2025/05/05 初版