# test コマンド概要

`test` コマンドは、ファイルの種類や属性の確認、文字列や数値の比較など、条件評価を行うためのUnixコマンドです。主にシェルスクリプト内で条件分岐に使用されます。

## オプション

### **ファイル関連のテスト**:

ファイルの存在や種類、属性を確認するオプションです。

```bash
$ test -f /etc/passwd && echo "ファイルが存在します"
ファイルが存在します

$ test -d /etc && echo "ディレクトリが存在します"
ディレクトリが存在します
```

### **文字列関連のテスト**:

文字列の比較や空文字列のチェックを行うオプションです。

```bash
$ test "abc" = "abc" && echo "文字列は等しいです"
文字列は等しいです

$ test -z "" && echo "空文字列です"
空文字列です
```

### **数値関連のテスト**:

数値の比較を行うオプションです。

```bash
$ test 10 -gt 5 && echo "10は5より大きいです"
10は5より大きいです

$ test 3 -eq 3 && echo "3は3と等しいです"
3は3と等しいです
```

## 主なオプション一覧

### ファイル関連

- **-f ファイル名**: 通常のファイルが存在するかチェックします
- **-d ディレクトリ名**: ディレクトリが存在するかチェックします
- **-e パス**: ファイルまたはディレクトリが存在するかチェックします
- **-r ファイル名**: ファイルが読み取り可能かチェックします
- **-w ファイル名**: ファイルが書き込み可能かチェックします
- **-x ファイル名**: ファイルが実行可能かチェックします
- **-s ファイル名**: ファイルが空でないかチェックします

### 文字列関連

- **-z 文字列**: 文字列が空かチェックします
- **-n 文字列**: 文字列が空でないかチェックします
- **文字列1 = 文字列2**: 二つの文字列が等しいかチェックします
- **文字列1 != 文字列2**: 二つの文字列が異なるかチェックします

### 数値関連

- **n1 -eq n2**: n1とn2が等しいかチェックします
- **n1 -ne n2**: n1とn2が等しくないかチェックします
- **n1 -gt n2**: n1がn2より大きいかチェックします
- **n1 -ge n2**: n1がn2以上かチェックします
- **n1 -lt n2**: n1がn2より小さいかチェックします
- **n1 -le n2**: n1がn2以下かチェックします

## 使用例

### 基本的な使い方

```bash
$ test -f /etc/hosts && echo "ファイルが存在します"
ファイルが存在します

$ test -d /nonexistent || echo "ディレクトリが存在しません"
ディレクトリが存在しません
```

### if文との組み合わせ

```bash
$ if test -f /etc/passwd; then
>   echo "パスワードファイルが存在します"
> fi
パスワードファイルが存在します
```

### 角括弧構文（代替構文）

`test` コマンドは `[ ]` で代替できます。

```bash
$ [ -f /etc/hosts ] && echo "ファイルが存在します"
ファイルが存在します

$ if [ "hello" = "hello" ]; then
>   echo "文字列は等しいです"
> fi
文字列は等しいです
```

## よくある質問

### Q1. `test` コマンドと `[ ]` の違いは何ですか？
A. 機能的には同じです。`[ ]` は `test` コマンドの別名（シンボリックリンク）で、より読みやすい構文を提供します。ただし、`[` の後と `]` の前には必ずスペースが必要です。

### Q2. 複数の条件を組み合わせるにはどうすればいいですか？
A. `-a`（AND）と `-o`（OR）演算子を使用するか、`&&` や `||` を使って複数の `test` コマンドを連結できます。
```bash
$ [ -f /etc/hosts -a -r /etc/hosts ] && echo "ファイルが存在し、読み取り可能です"
```

### Q3. ファイルが存在しない場合にのみコマンドを実行するにはどうすればいいですか？
A. `!` 演算子または `||` を使用します。
```bash
$ [ ! -f /tmp/tempfile ] && echo "ファイルが存在しません"
# または
$ [ -f /tmp/tempfile ] || echo "ファイルが存在しません"
```

## 追加情報

- `test` コマンドは終了ステータスを返すだけで、標準出力には何も出力しません。そのため、通常は `&&` や `||` と組み合わせるか、`if` 文の条件として使用します。
- 最近のシェルでは、より強力な `[[ ]]` 構文（bash, zsh, ksh）も利用できます。これは `test` や `[ ]` の拡張版で、正規表現マッチングなどの追加機能があります。
- 数値比較では、変数が数値であることを確認してから使用することをお勧めします。数値でない場合、予期しない結果になることがあります。